jupyter\_core package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   jupyter_core.utils

Submodules
----------


.. automodule:: jupyter_core.application
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: jupyter_core.command
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: jupyter_core.migrate
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: jupyter_core.paths
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: jupyter_core.troubleshoot
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: jupyter_core.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jupyter_core
   :members:
   :undoc-members:
   :show-inheritance:
